pub enum DetectResult {
Match {
confidence: u8,
},
NeedMore {
minimum: usize,
},
NoMatch,
}Expand description
Result of a protocol detection attempt.
Variants
Match
The protocol was matched with the given confidence level (0–100).
NeedMore
More data is needed; minimum is the smallest number of total prefix
bytes required before a definitive result can be given.
NoMatch
This prefix does not match the protocol.